import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataKubernetesNamespaceConfig extends cdktf.TerraformMetaArguments {
    /**
    * metadata block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/namespace#metadata DataKubernetesNamespace#metadata}
    */
    readonly metadata: DataKubernetesNamespaceMetadata;
}
export declare class DataKubernetesNamespaceSpec extends cdktf.ComplexComputedList {
    get finalizers(): string[];
}
export interface DataKubernetesNamespaceMetadata {
    /**
    * An unstructured key value map stored with the namespace that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/namespace#annotations DataKubernetesNamespace#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * Map of string keys and values that can be used to organize and categorize (scope and select) the namespace. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/namespace#labels DataKubernetesNamespace#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Name of the namespace, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/namespace#name DataKubernetesNamespace#name}
    */
    readonly name?: string;
}
export declare function dataKubernetesNamespaceMetadataToTerraform(struct?: DataKubernetesNamespaceMetadataOutputReference | DataKubernetesNamespaceMetadata): any;
export declare class DataKubernetesNamespaceMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): DataKubernetesNamespaceMetadata | undefined;
    set internalValue(value: DataKubernetesNamespaceMetadata | undefined);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    get generation(): number;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    get resourceVersion(): string;
    get uid(): string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/kubernetes/d/namespace kubernetes_namespace}
*/
export declare class DataKubernetesNamespace extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/d/namespace kubernetes_namespace} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataKubernetesNamespaceConfig
    */
    constructor(scope: Construct, id: string, config: DataKubernetesNamespaceConfig);
    get id(): string;
    spec(index: string): DataKubernetesNamespaceSpec;
    private _metadata;
    get metadata(): DataKubernetesNamespaceMetadataOutputReference;
    putMetadata(value: DataKubernetesNamespaceMetadata): void;
    get metadataInput(): DataKubernetesNamespaceMetadata | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
